# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['deepcode']

package_data = \
{'': ['*']}

install_requires = \
['aiodns>=2.0.0,<3.0.0',
 'aiohttp>=3.6.2,<4.0.0',
 'cchardet>=2.1.5,<3.0.0',
 'click-option-group>=0.2.3,<0.3.0',
 'click>=7.0,<8.0',
 'funcy>=1.14,<2.0',
 'tqdm>=4.42.1,<5.0.0']

entry_points = \
{'console_scripts': ['deepcode = deepcode.cli:main']}

setup_kwargs = {
    'name': 'deepcode',
    'version': '1.0.18',
    'description': 'A client for DeepCode API (code analysis made by AI)',
    'long_description': "# DeepCode's command line interface.\n\n[![deepcode](https://www.deepcode.ai/api/gh/badge?key=eyJhbGciOiJIUzI1NiIsInR5cCI6IkpXVCJ9.eyJwbGF0Zm9ybTEiOiJnaCIsIm93bmVyMSI6IkRlZXBDb2RlQUkiLCJyZXBvMSI6ImNsaSIsImluY2x1ZGVMaW50IjpmYWxzZSwiYXV0aG9ySWQiOjEyNDY5LCJpYXQiOjE1OTYwOTY5Njd9.NAHffzuy6KvoVYXF6VyTIVHccXqr2ZGW5ATcv7PlsqI)](https://www.deepcode.ai/app/gh/DeepCodeAI/cli/_/dashboard?utm_content=gh%2FDeepCodeAI%2Fcli)\n\n## Installation\n\nMinimal supported python version is: 3.6.5\n\n### Installation of published package from PyPI\n\nPip:\n```bash\npip install deepcode\n```\n\nPoetry:\n```bash\npoetry add deepcode\n```\n\nFor detailed information see [deepcode project on PYPI](https://pypi.org/project/deepcode/)\n\n### Installation of package locally and development mode\n\nFor detailed information see [development docs](https://github.com/DeepCodeAI/cli/blob/master/docs/Development.md)\n\n\n## CLI\n\n```bash\ndeepcode --help\n\nUsage: deepcode [OPTIONS] COMMAND [ARGS]...\n\n  A tool, that detects bugs and quality issues in JavaScript, TypeScript,\n  Python, Java and C/C++. It uses a mighty engine based on AI from Deepcode.\n\nOptions:\n  -s, --service-url TEXT  Custom DeepCode service URL (default:\n                          https://www.deepcode.ai)\n  -a, --api-key TEXT      Deepcode API key\n  -c, --config-file FILE  Config file (default: ~/.deepcode.json)\n  --help                  Show this message and exit.\n\nCommands:\n  analyze  Analyzes your code using Deepcode AI engine.\n  config   Store configuration values in a file.\n  login    Initiate a new login protocol.\n```\n\n\n- login: this will open a browser window to log into DeepCode.\n  ```bash\n  deepcode login\n  ```\n- create/update configuration: this will walk you through some configuration steps in case you do not want to connect to\n  https://www.deepcode.ai but to some other host running a DeepCode instance.\n  ```bash\n  deepcode config\n  ```\n- analyze: do analysis for a specific version of code. This will show all suggestions that are present in the code.\n\n```\nUsage: deepcode analyze [OPTIONS]\n\n  Analyzes your code using Deepcode AI engine.\n\n  Exit codes:\n  0 - not issues found\n  1 - some issues found\n  2 - Execution was interrupted by the user\n  3 - Some error happened while executing\n\nOptions:\n  Source location: [mutually_exclusive, required]\n                                  The configuration of repository location\n    -p, --path DIRECTORY          Path to folder to be processed. Multiple\n                                  paths are allowed\n    -r, --git-uri REMOTE          Git URI (e.g.\n                                  git@<platform>:<owner>/<repo>.git@<oid> or\n                                  https://<platform>/<owner>/<repo>.git@<oid>)\n  -l, --with-linters              Enable linters\n  -log, --log-file FILE           Forward all debugging messages to a file\n  -txt, --result-text             Present results in txt format\n  -sev, --severity [info|warning|critical]\n                                  Minimum severity level (default: info)\n  --help                          Show this message and exit.\n```\n\nExamples:\n\n```bash\ndeepcode analyze --path (<folder path one>) --path (<folder path two>) --with-linters --log-file=~/.deepcode.log -txt --severity warning\n\ndeepcode analyze --path (<folder path one>)\ndeepcode analyze --git-uri git@github.com:DefinitelyTyped/DefinitelyTyped.git --with-linters\n```\n\nAnalysisResults in json format as described [here](https://www.deepcode.ai/docs/REST%20APIs%2FBundles)\n\n## Python native usage\n\nDeepCode CLI can be also used as a module and can be imported into another python code with python import system.\n\nTo use both functions, make sure, you set an environment variable 'DEEPCODE_API_KEY' with your API KEY, that [can be obtained here](https://www.deepcode.ai/app/~platform/account)\n\nTo use self-managed instance of Deepcode, set an environment variable 'DEEPCODE_SERVICE_URL' with its user (e.g. https://example.org)\n\nAvailable methods:\n\n- analyze_folders(paths, linters_enabled=False):\n\n  ````\n  :param [paths] - Paths should be a list of absolute paths to bundle dir\n  :param [linters_enabled] - optional. requests also linter analysis\n  :return - dictionary with results e.g. as described [here](https://www.deepcode.ai/docs/REST%20APIs%2FBundles) plus: 'id' for bundle id and 'url' for online view of analysis results\n\n  example:\n  import deepcode\n  deepcode.analyze_folders('<path to files dir>')\n  ````\n\n- analyze_git(platform, owner, repo, oid=None, linters_enabled=False):\n\n  ````\n  :param [platform] - github.com, bitbucket.org, gitlab.com.\n  :param [owner] - repository account. (e.g. facebook)\n  :param [repo] - repository. (e.g. react)\n  :param [linters_enabled] - optional. requests also linter analysis\n  :return - dictionary with results e.g. as described [here](https://www.deepcode.ai/docs/REST%20APIs%2FBundles) plus: 'id' for bundle id and 'url' for online view of analysis results\n\n  example:\n  import deepcode\n  deepcode.analyze_git('github.com', 'facebook', 'react')\n  ````\n",
    'author': 'Deepcode',
    'author_email': 'accounts@deepcode.ai',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://www.deepcode.ai',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)
